// KreateCD - CD recording software for the K desktop environment
//
// 1998-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
//
// This file is subject to the terms and conditions of the GNU General
// Public License.  See the file COPYING in the main directory of the
// KreateCD distribution for more details.

#ifndef TOPWIDGET_INCLUDED
#define TOPWIDGET_INCLUDED

#include <kmainwindow.h>

class TopWidget : public KMainWindow {
  Q_OBJECT;

 public:
  TopWidget(const char *name = 0L);
  ~TopWidget(void);
         
  public slots:
    void leaveMe(void);

};

#endif
